using System;
using System.Collections.Generic;

namespace Rhino.Mocks.Demo
{
	public class LoginController
	{
		private readonly ISmsSender sender;
		private readonly IUserRepository userRepository;
		private ICollection<string> slaVilations = new List<string>();
		private TimeSpan maxAllowedDuration = TimeSpan.FromSeconds(3);

		public LoginController(ISmsSender sender, IUserRepository userRepository)
		{
			this.sender = sender;
			this.userRepository = userRepository;
		}

		public ICollection<string> SlaVilations
		{
			get { return slaVilations; }
		}

		public void SendNewPassword(string userId)
		{
			User user = userRepository.GetById(userId);
			if(user==null)
				return;
			string oldPass = user.Password ;
			user.Password = GetNewPass_DO_NOT_USE_FOR_REAL_CODE();
			DateTime start = DateTime.Now;
			try
			{
				sender.SendSms(user.Phone, "New passord: " + user.Password);
			}
			catch (Exception e)
			{
				// logger.Error("When sending SMS", e);
				user.Password = oldPass;
			}
			TimeSpan duration = DateTime.Now - start;
			if(duration> MaxAllowedDuration)
			{
				SlaVilations.Add(string.Format("Expected to take {0} but took {1} to send SMS to {2}", MaxAllowedDuration, duration, user.Name));
			}
		}

		private static string GetNewPass_DO_NOT_USE_FOR_REAL_CODE()
		{
			byte[] buffer = new byte[15];
			new Random().NextBytes(buffer);
			return Convert.ToBase64String(buffer);
		}

		public TimeSpan MaxAllowedDuration
		{
			get { return maxAllowedDuration; }
			set { maxAllowedDuration = value; }
		}
	}
}